==> haskell-pqueue-1.5.0.0-43.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pqueue.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pqueue
version:              1.5.0.0
visibility:           public
id:                   pqueue-1.5.0.0-uLmpwEBc6yDEnAvLHhhiQ
key:                  pqueue-1.5.0.0-uLmpwEBc6yDEnAvLHhhiQ
license:              BSD-3-Clause
maintainer:
    Lennart Spitzner <hexagoxel@hexagoxel.de>,
    Louis Wasserman <wasserman.louis@gmail.com>,
    konsumlamm <konsumlamm@gmail.com>,
    David Feuer <David.Feuer@gmail.com>

author:               Louis Wasserman
stability:            experimental
homepage:             https://github.com/lspitzner/pqueue
synopsis:             Reliable, persistent, fast priority queues.
description:
    A fast, reliable priority queue implementation based on a binomial heap.

category:             Data Structures
abi:                  73a993fd02cbb39c4fa2c69dc3a17ddc
exposed:              True
exposed-modules:
    Data.PQueue.Max Data.PQueue.Min Data.PQueue.Prio.Max
    Data.PQueue.Prio.Min

hidden-modules:
    Data.PQueue.Prio.Internals Data.PQueue.Internals
    BinomialQueue.Internals BinomialQueue.Min BinomialQueue.Max
    Data.PQueue.Internals.Down Data.PQueue.Internals.Foldable
    Data.PQueue.Prio.Max.Internals Nattish

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pqueue-1.5.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pqueue-1.5.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pqueue-1.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pqueue
hs-libraries:         HSpqueue-1.5.0.0-uLmpwEBc6yDEnAvLHhhiQ
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr

haddock-interfaces:   /usr/share/doc/haskell-pqueue/html/pqueue.haddock
haddock-html:         /usr/share/doc/haskell-pqueue/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pqueue-1.5.0.0-44-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pqueue.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pqueue
version:              1.5.0.0
visibility:           public
id:                   pqueue-1.5.0.0-eznI7Hz25Z2Yep2vFVa8v
key:                  pqueue-1.5.0.0-eznI7Hz25Z2Yep2vFVa8v
license:              BSD-3-Clause
maintainer:
    Lennart Spitzner <hexagoxel@hexagoxel.de>,
    Louis Wasserman <wasserman.louis@gmail.com>,
    konsumlamm <konsumlamm@gmail.com>,
    David Feuer <David.Feuer@gmail.com>

author:               Louis Wasserman
stability:            experimental
homepage:             https://github.com/lspitzner/pqueue
synopsis:             Reliable, persistent, fast priority queues.
description:
    A fast, reliable priority queue implementation based on a binomial heap.

category:             Data Structures
abi:                  61776e47b7aa022683f768fd2e540317
exposed:              True
exposed-modules:
    Data.PQueue.Max Data.PQueue.Min Data.PQueue.Prio.Max
    Data.PQueue.Prio.Min

hidden-modules:
    Data.PQueue.Prio.Internals Data.PQueue.Internals
    BinomialQueue.Internals BinomialQueue.Min BinomialQueue.Max
    Data.PQueue.Internals.Down Data.PQueue.Internals.Foldable
    Data.PQueue.Prio.Max.Internals Nattish

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pqueue-1.5.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pqueue-1.5.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pqueue-1.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pqueue
hs-libraries:         HSpqueue-1.5.0.0-eznI7Hz25Z2Yep2vFVa8v
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr

haddock-interfaces:   /usr/share/doc/haskell-pqueue/html/pqueue.haddock
haddock-html:         /usr/share/doc/haskell-pqueue/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
